@@ -23,6 +23,7 @@ from bnlearn.bnlearn import (
     independence_test,
     save,
     load,
+    check_model,
 )
 
 # Import function in new level
@@ -35,7 +36,7 @@ from packaging import version
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '0.7.6'
+__version__ = '0.7.7'
 
 try:
     import pgmpy
@@ -109,9 +110,9 @@ Example
 
 References
 ----------
-* https://bnlearn.readthedocs.io
-* https://github.com/erdogant/bnlearn
-* https://towardsdatascience.com/a-step-by-step-guide-in-detecting-causal-relationships-using-bayesian-structure-learning-in-python-c20c6b31cee5
-* https://towardsdatascience.com/a-step-by-step-guide-in-designing-knowledge-driven-models-using-bayesian-theorem-7433f6fd64be
+* Blog1: https://towardsdatascience.com/a-step-by-step-guide-in-detecting-causal-relationships-using-bayesian-structure-learning-in-python-c20c6b31cee5
+* Blog2: https://towardsdatascience.com/a-step-by-step-guide-in-designing-knowledge-driven-models-using-bayesian-theorem-7433f6fd64be
+* Github: https://github.com/erdogant/bnlearn
+* Documentation: https://bnlearn.readthedocs.io
 
 """
