@@ -5,6 +5,26 @@ from pgmpy.models import BayesianNetwork, NaiveBayes
 from pgmpy.estimators import ExhaustiveSearch, HillClimbSearch, TreeSearch
 from pgmpy.factors.discrete import TabularCPD
 
+# %% Issue #60: Floating Point Errors.
+import bnlearn as bn
+
+# Load example dataset
+df = bn.import_example('sprinkler')
+
+edges = [('Cloudy', 'Sprinkler'),
+         ('Cloudy', 'Rain'),
+         ('Sprinkler', 'Wet_Grass'),
+         ('Rain', 'Wet_Grass')]
+
+# Make the actual Bayesian DAG
+DAG = bn.make_DAG(edges)
+model = bn.parameter_learning.fit(DAG, df)
+# Print CPDs
+CPD = bn.print_CPD(model)
+
+bn.check_model(CPD) # Input should be model
+bn.check_model(model)
+
 # %%
 import bnlearn as bn
 # print(bn.__version__)
@@ -12,6 +32,14 @@ import bnlearn as bn
 # print(dir(bn.parameter_learning))
 # print(dir(bn.inference))
 
+# %%
+# Load asia DAG
+df = bn.import_example(data='asia')
+# Structure learning of sampled dataset
+model = bn.structure_learning.fit(df)
+# Make plot
+G = bn.plot(model)
+
 # %% Issue MAIL: Store CPDs after printing.
 
 import bnlearn as bn
@@ -432,7 +460,7 @@ print(cpd_C)
 cpd_D = TabularCPD(variable='D', variable_card=2, values=[[0.4, 0.9], [0.6, 0.1]], evidence=['A'], evidence_card=[2])
 print(cpd_D)
 
-DAG = bn.make_DAG(DAG, CPD=[cpd_A, cpd_B, cpd_C, cpd_D], checkmodel=False)
+DAG = bn.make_DAG(DAG, CPD=[cpd_A, cpd_B, cpd_C, cpd_D], checkmodel=True)
 bn.print_CPD(DAG, checkmodel=True)
 
 # %% Adjust some edge properties
@@ -1028,6 +1056,8 @@ vector = bn.adjmat2vec(DAG['adjmat'])
 adjmat = bn.vec2adjmat(vector['source'], vector['target'])
 
 # %%
+import bnlearn as bn
+
 edges = [('A', 'E'),
          ('S', 'E'),
          ('E', 'O'),
@@ -1053,8 +1083,8 @@ cpd_E = TabularCPD(variable='E', variable_card=2,
 print(cpd_E)
 
 
-DAG = bn.make_DAG(DAG, CPD=cpd_A, checkmodel=False)
-bn.print_CPD(DAG, checkmodel=False)
+DAG = bn.make_DAG(DAG, CPD=cpd_A, checkmodel=True)
+bn.print_CPD(DAG, checkmodel=True)
 
 # %% Create a simple DAG:
 # Building a causal DAG
@@ -1096,7 +1126,7 @@ print(cpt_wet_grass)
 # The make_DAG function will required a CPD for each node. If this is not the case, use the checkmodel=False
 DAG = bn.make_DAG(DAG, CPD=cpt_cloudy, checkmodel=False)
 DAG = bn.make_DAG(DAG, CPD=[cpt_cloudy, cpt_sprinkler], checkmodel=False)
-DAG = bn.make_DAG(DAG, CPD=[cpt_cloudy, cpt_sprinkler, cpt_rain, cpt_wet_grass])
+DAG = bn.make_DAG(DAG, CPD=[cpt_cloudy, cpt_sprinkler, cpt_rain, cpt_wet_grass], checkmodel=True)
 bn.print_CPD(DAG)
 
 q1 = bn.inference.fit(DAG, variables=['Wet_Grass'], evidence={'Rain': 1, 'Sprinkler': 0, 'Cloudy': 1})
